***************************
*    DATA CREATION		  *
***************************

* MERGE ADOPTION FILES *

	set more off	
	
	use "$folder/Ad2015v1.dta",clear
	* Correct adoption date
	gen newdate=ustrleft(adoptdate, 10)
	gen AdoptDate=date(newdate, "YMD")
	drop newdate
	format AdoptDate %td
	* Correct dob
	gen newdate=ustrleft(dob, 10)
	gen dob_new=date(newdate, "YMD")
	drop newdate
	format dob_new %td
	drop dob
	rename dob_new dob
	save "$folder/Ad2015_correcteddates.dta", replace
				
	use "$folder/Ad2002v6.dta",clear
	qui append using "$folder/Ad2003v7.dta"
	qui append using "$folder/Ad2004v6.dta"
	qui append using "$folder/Ad2005v5.dta"
	qui append using "$folder/Ad2006v5.dta"
	qui append using "$folder/Ad2007v5.dta"
	qui append using "$folder/Ad2008v5.dta"
	qui append using "$folder/Ad2009v5.dta"
	qui append using "$folder/Ad2010v3.dta"
	qui append using "$folder/Ad2011v3.dta"
	qui append using "$folder/Ad2012v2.dta"
	qui append using "$folder/Ad2013v1.dta"
	qui append using "$folder/Ad2014v1.dta"
	qui append using "$folder/Ad2015_correcteddates.dta"

	* MONETARY VARIABLES
		
		* MERGE IN CPI
		gen year=year(AdoptDate)
		merge m:1 year using "$folder/cpi.dta"
		keep if _merge==3
		drop _merge
		
		* INFLATE SUBSIDY VARIABLE TO 2012 DOLLARS
		gen monamnt_inf=(monamnt*229.755)/cpi
		
		* INDICATOR FOR ANY SUBSIDY RECEIPT
		gen subsidy=monsubsy==1
		replace subsidy=. if missing(monsubsy)
		
	* SPECIAL NEEDS VARIABLES
		gen sn=.
		replace sn=1 if agyspnds==1
		replace sn=0 if agyspnds==2
		replace sn=1 if !missing(basspnds) & basspnds!=0
		
		replace bass=0 if sn==0
		gen sn_race=sn==1 & bass==1
			replace sn_race=. if missing(sn)
		gen sn_age=sn==1 & bass==2
			replace sn_age=. if missing(sn)
		gen sn_sib=sn==1 & bass==3
			replace sn_sib=. if missing(sn)
		gen sn_med=sn==1 & bass==4
			replace sn_med=. if missing(sn)
		gen sn_other=sn==1 & bass==5
			replace sn_other=. if missing(sn)
		gen sn_missing=sn==1 & missing(basspnds)
		
		gen spnds=agyspnds==1
		replace spnds=. if missing(agyspnds)
		
		gen nonsn=-1*sn+1
		
	*Adoptive family structure
		gen married=adpfamst==1
		replace married=. if missing(adpfamst)
		gen unmarried=adpfamst==2
		replace unmarried=. if missing(adpfamst)
		gen singlef=adpfamst==3
		replace singlef=. if missing(adpfamst)
		gen singlem=adpfamst==4
		replace singlem=. if missing(adpfamst)
		
	* COUNT BY: 
		* count
		gen adopt=1
		gen dm=mofd(AdoptDate)
		gen dm_date=dm
		format dm_date %tm
		
		*Drop variables with all missing observations
		foreach var of varlist _all {
		capture assert mi(`var')
		if !_rc {
		   drop `var'
		}
		}
			
	*Biological mom marital status
		gen mommarried=momarrd==1
		replace mommarried=. if missing(momarrd)
		
	*Age variables
		gen admomage=year(AdoptDate)-admomyr
		gen addadage=year(AdoptDate)-addadyr
		gen momage_atbirth=year(dob)-dobyrmom
		gen dadage_atbirth=year(dob)-dobyrdad

	*Child age
		replace AgeAtAdopt=ageatadopt if missing(AgeAtAdopt)
		
	* Older relative
		gen agediff=admomage-AgeAtAdopt
		gen olderrel=otherel==1 & agediff>=35

	* Race variables
		replace ChildRace=childrace if missing(ChildRace)
		replace MomRace=momrace if missing(MomRace)
		replace DadRace=dadrace if missing(DadRace)
		xi i.ChildRace i.MomRace i.DadRace, noomit
		rename _IChildRace_1 nonhispwhite
		rename _IChildRace_2 nonhispblack
		rename _IChildRace_7 hispanic
		gen other=_IChildRace_3+_IChildRace_4+_IChildRace_5+_IChildRace_6+_IChildRace_99
		
		rename _IMomRace_1 nonhispwhitem
		rename _IMomRace_2 nonhispblackm
		rename _IMomRace_7 hispanicm
		gen otherm=_IMomRace_3+_IMomRace_4+_IMomRace_5+_IMomRace_6+_IMomRace_99
		
		rename _IDadRace_1 nonhispwhited
		rename _IDadRace_2 nonhispblackd
		rename _IDadRace_7 hispanicd
		gen otherd=_IDadRace_3+_IDadRace_4+_IDadRace_5+_IDadRace_6+_IDadRace_99

	***** DROP STEP PARENT ADOPTIONS BECAUSE INELIGIBLE FOR TAX CREDIT ***
		drop if stparent==1
	
	* PRE-ADOPTIVE RELATIONSHIP: MUTUALLY EXCLUSIVE VARIABLES
	* Un-related foster family, non-foster relative, nonrelative 
	*(neither relative nor foster parent prior to adoption) 
		gen preadoptive=.
		replace preadoptive=1 if fosparch==1 & otherel==0
		replace preadoptive=1 if fosparch==1 & nonrel==1
		replace preadoptive=1 if fosparch==1 & missing(otherel) & missing(nonrel)
		replace preadoptive=2 if fosparch==0 & otherel==1
		replace preadoptive=2 if otherel==1 & missing(fosparch) & missing(nonrel)
		replace preadoptive=2 if otherel==1 & missing(fosparch) & nonrel==0
		replace preadoptive=3 if fosparch==0 & otherel==0
		replace preadoptive=3 if nonrel==1 & missing(fosparch) & missing(otherel)
		replace preadoptive=3 if nonrel==1 & missing(fosparch) & otherel==0
		replace preadoptive=3 if nonrel==1 & missing(otherel) & fosparch==0
		replace preadoptive=4 if fosparch==1 & otherel==1
		
		label define preadoptive 1 "Unrelated foster family" 2 "relative (non-foster family)" 3 "non-relative (non-foster family)" 4 "relative foster family"
		label values preadoptive preadoptive
		
		xi i.preadoptive, noomit
		rename _Ipreadopti_1 unrelatedfosterfam
		rename _Ipreadopti_2 relative
		rename _Ipreadopti_3 nonrelative
		rename _Ipreadopti_4 relatedfosterfam
	
save "$folder/temp_ad.dta",replace
	
