***********************************************
*                GRAPHS                       * 
***********************************************

* FIGURE 1: MAXIMUM TAX CREDIT AMOUNT PER YEAR

	use "$folder/taxcreditamounts.dta", clear
	
	twoway (line maxamount year, graphregion(color(white)) xlabel(1997(1)2017, angle(45)) ///
	ylabel(0(2500)15000) ytitle(Maximum Credit Amount) xtitle(Tax Year) ///
	note("Source: IRS Form 8839, Qualified Adoption Expenses, Department of the Treasury," ///
	"Internal Revenue Service.") lcolor(black)) ///
	(scatter maxamount year if year<2010 | year>2011, mcolor(black) msize(small) msymbol(Oh)) ///
	(scatter maxamount year if year>=2010 & year<=2011, mcolor(black) legend(order(2 "Nonrefundable" 3 "Refundable")))

	graph save "$folder/figure1", asis replace
	
* FIGURE 2: TAX EXPENDITURES ON FEDERAL ADOPTION TAX CREDIT AND NUMBER OF RETURNS
	use "$folder/taxexpenditures.dta",clear
	
	#delimit;
		twoway (line taxexpenditure year, graphregion(color(white)) 
		ylabel(0(.2)1.4, axis(1)) xlabel(1997(1)2014, angle(45)) 
		legend(order(2 4) label(2 Amount) label(4 Returns)) xtitle(Year) ytitle("Billions of dollars") lcolor(gs6))
		(scatter taxexpenditure year, msize(small) msymbol(Oh) mcolor(gs6)
		note("Sources: Internal Revenue Service, Statistics of Income, Individual Income Tax Returns,"
		"Publication 1304, Table 3.3, Tax Years 1997-2014."))  
		(line numberreturns year, yaxis(2) ytitle("Thousands of Returns", axis(2)) lcolor(black))
		(scatter numberreturns year, msize(small) msymbol(dh) mcolor(black) yaxis(2));
	#delimit cr
	
	graph save "$folder/figure2.gph", replace

* FIGURE 3: ANNUAL LEVEL NUMBER OF ADOPTIONS
	use "$folder/temp_ad.dta",clear
	collapse (sum) adopt, by(year)
	
	* Number of children adopted by year
	#delimit ; 
	twoway (line adopt year if year>2001 & year<=2014, graphregion(color(white))
	lcolor(black)
	xtitle(Calendar Year of Adoption)
	ytitle(Number of Adoptions)	
	ylabel(0(20000)60000)
	xlabel(2002(1)2014, angle(45))
	note("Sources and notes: AFCARS Adoption Files, 2002-2015."))
	(scatter adopt year if year>2001 & year<=2014, msymbol(Oh) mcolor(black) legend(off));
	#delimit cr
	
	graph save "$folder/figure3.gph", asis replace

* FIGURE 4: MONTHLY LEVEL NUMBER OF ADOPTIONS
	use "$folder/temp_ad.dta",clear
				
	collapse (sum) adopt, by(dm) /*Count the number of children adopted each month*/
		
	*Graph of number of children adopted by month
	* TITLE "NUMBER OF ADOPTIONS BY FINALIZATION MONTH"
		
	drop if missing(dm)
	gen date=dm
	format date %tm
	
	* 2007-2015
	#delimit ; 
	twoway line adopt dm if dm>=564 & dm<=659, lpattern(solid) lcolor(black) graphregion(color(white))
	xlabel(564 "Jan 07" 576 "Jan 08" 588 "Jan 09" 600 "Jan 10" 612 "Jan 11" 624 "Jan 12" 636 "Jan 13" 648 "Jan 14")
	xtitle(Month) ylabel(0(1000)8000, angle(0)) xline(600 624, lcolor(gs6)) xline(636, lpattern(-) lcolor(gs6)) text(1500 612 "Refundable Credit")
	ytitle(Number of Adoptions)	
	note("Sources and notes: AFCARS Adoption Files, 2007-2015.") ;
	#delimit cr
			
	graph save "$folder/figure4.gph", asis replace


