* The code in this file replicates output provided in 
* Tables 2-5 and replicates Figure 5. 

cap log close
log using "$folder/${date_string}_tables2_5_figure_5.log", replace 

***************************
*        TABLE 2          *
***************************


use "$folder/temp_ad.dta",clear
set more off	
collapse (sum) adopt, by(AdoptDate)

gen year=year(AdoptDate)
gen month=month(AdoptDate)
gen day=day(AdoptDate)

sort month day year
fillin month day year
replace AdoptDate=mdy(month, day, year) if missing(AdoptDate)
drop if missing(AdoptDate)
drop if AdoptDate<=mdy(1,1,2000)
replace adopt=0 if _fillin==1
			
gen doy=mdy(month, day, 1968)
gen dow=dow(AdoptDate) /* 0 is sunday */

gen dm=mofd(AdoptDate)

drop if AdoptDate<mdy(7,1,2002)
drop if AdoptDate>=mdy(10,1,2015)

sort AdoptDate
			
gen natadoptionday=0
replace natadoptionday=1 if AdoptDate==mdy(11,23,2002)
replace natadoptionday=1 if AdoptDate==mdy(11,22,2003)
replace natadoptionday=1 if AdoptDate==mdy(11,20,2004)
replace natadoptionday=1 if AdoptDate==mdy(11,19,2005)
replace natadoptionday=1 if AdoptDate==mdy(11,18,2006)
replace natadoptionday=1 if AdoptDate==mdy(11,17,2007)
replace natadoptionday=1 if AdoptDate==mdy(11,22,2008)
replace natadoptionday=1 if AdoptDate==mdy(11,21,2009)
replace natadoptionday=1 if AdoptDate==mdy(11,20,2010)
replace natadoptionday=1 if AdoptDate==mdy(11,19,2011)
replace natadoptionday=1 if AdoptDate==mdy(11,24,2012)
replace natadoptionday=1 if AdoptDate==mdy(11,23,2013)
replace natadoptionday=1 if AdoptDate==mdy(11,22,2014)
			
gen t_start=dm-600
gen t_end=dm-623
gen exclude=t_start==-1 | t_start==0 | t_end==0 | t_end==1

* POLYNOMIAL OF TIME
* Start at July 2002 (dm=510; date=15522)
gen t=AdoptDate-15522
forvalues order = 1/6 {
	gen t`order' = t^`order'
	}


	* Around credit introduction 
	
	* REGRESSIONS PROGRAMS *
	
		cap program drop summarystats
		prog def summarystats, rclass
			args type
			
			forvalues order = 3/5 {
			qui reg `type' t1-t`order' i.dow i.month i.year i.natadoptionday if exclude==0, cluster(doy)
			di `order'
			predict y_hat 		
			egen total_actual=sum(`type'), by(dm)
			egen total_y_hat=sum(y_hat), by(dm)
			gen diff= total_actual - total_y_hat
			sum diff if t_start==-1
			sum diff if t_start==0
			
			sum total_y_hat if t_start ==-1
			sum total_actual if t_start==-1

			sum total_y_hat if t_start==0
			sum total_actual if t_start==0
	
			drop y_hat diff total_y_hat total_actual		
				}
			
		end
		
		* RUN PROGRAM
		summarystats adopt
				
		* BUNCHING PROGRAM AROUND 2010 (January 1, 2010) 
			
		cap program drop bunch_2010
			prog def bunch_2010, rclass
			args type order
			reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
			predict y_hat 																		/* predict values for all observations */
			gen diff= `type' - y_hat
			egen total=sum(diff), by(dm)
			* December 2009
			sum total if t_start==-1
			return scalar diff_avg_dec=r(mean)
			* January 2010
			sum total if t_start==0
			return scalar diff_avg_jan=r(mean) 																/* Average across (y - yhat) for all observations */
			* December + January 
			egen total_combined=sum(diff) if dm>=599 & dm<=600
			sum total_combined if t_start==0
			return scalar diff_avg_all=r(mean) 	
			drop y_hat diff total total_combined
		end
		
		* Bunching estimates looping through order, 3-5
		
	
		foreach var of varlist adopt  {
			forval i=3/5 {
				local type `var' `i'
				bootstrap diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_all=r(diff_avg_all), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' 
		}
		}
		
		

	* Around credit expiration
		
			cap program drop summarystats_2012
			prog def summarystats_2012, rclass
			args type
			
			forvalues order = 3/5 {
			qui reg `type' t1-t`order' i.dow i.month i.year i.natadoptionday if exclude==0, cluster(doy)
			di `order'
			predict y_hat 		
			egen total_actual=sum(`type'), by(dm)
			egen total_y_hat=sum(y_hat), by(dm)
			gen diff= total_actual - total_y_hat
			sum diff if t_end==0
			sum diff if t_end==1
			
			sum total_y_hat if t_end ==0
			sum total_actual if t_end==0

			sum total_y_hat if t_end==1
			sum total_actual if t_end==1
	
			drop y_hat diff total_y_hat total_actual	
				}
			
		end
		
		summarystats_2012 adopt

		
		* Bunching estimates
		
		cap program drop bunch_2012
			prog def bunch_2012, rclass
			args type order
			reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
			predict y_hat 																		/* predict values for all observations */
			gen diff= `type' - y_hat
			egen total=sum(diff), by(dm)
			* December 2011
			sum total if t_end==0
			return scalar diff_avg_dec=r(mean)
			* January 2012
			sum total if t_end==1
			return scalar diff_avg_jan=r(mean)  /* Average across (y - yhat) for all observations */
			* December + January 
			egen total_combined=sum(diff) if dm>=623 & dm<=624
			sum total_combined if t_end==0
			return scalar diff_avg_all=r(mean) 	
			drop y_hat diff total total_combined

		end
	
		* Bunching estimates looping through order, 3-5
		
		foreach var of varlist adopt {
			forval i=3/5 {
				local type `var' `i'
				bootstrap diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_all=r(diff_avg_all), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' 
		}
		}
		
	
		* FIGURE 5 
		reg adopt i.dow i.month i.year i.natadoptionday t1-t4 if exclude==0, cluster(doy)		
		predict adopt_hat 
			
		egen adopt_sum = sum(adopt), by(dm)
		egen adopt_hat_sum=sum(adopt_hat), by(dm)
		gen diff=adopt_sum-adopt_hat_sum

		twoway line diff dm, xlabel(510 "Jul 02" 516 "Jan 03" 528 "Jan 04" 540 "Jan 05" 552 "Jan 06" 564 "Jan 07" 576 "Jan 08" 588 "Jan 09" 600 "Jan 10" 612 "Jan 11" 624 "Jan 12" 636 "Jan 13" 648 "Jan 14" 660 "Jan 15", angle(45)) ///
		lpattern(solid) lcolor(black) ytitle(Actual - Predicted Adoptions) xtitle(Month) ylabel(-2000(500)2500, angle(0)) ///
		xline(600 624, lcolor(gs6)) legend(off) ///
		note("Sources and notes: AFCARS Adoption Files, 2002-2015.") graphregion(color(white))
				
		graph save "$folder/figure5.gph",asis replace

***************************
*        TABLE 3          *
***************************


* USE POLYNOMIAL OF 4
local poly= 4
	
	* AROUND BEGINNING 
	
		use "$folder/temp_ad.dta",clear
		set more off
			
		collapse (sum) adopt, by(AdoptDate)
		
		gen year=year(AdoptDate)
		gen month=month(AdoptDate)
		gen day=day(AdoptDate)
		
		sort month day year
		fillin month day year
		replace AdoptDate=mdy(month, day, year) if missing(AdoptDate)
		drop if missing(AdoptDate)
		drop if AdoptDate<=mdy(1,1,2000)
		replace adopt=0 if _fillin==1
	
		gen doy=mdy(month, day, 1968)
		gen dow=dow(AdoptDate) /* 0 is sunday */
		
		gen dm=mofd(AdoptDate)
		
		drop if AdoptDate<mdy(7,1,2002)
		drop if AdoptDate>=mdy(10,1,2015)
		
		sort AdoptDate
		
		gen natadoptionday=0
		replace natadoptionday=1 if AdoptDate==mdy(11,23,2002)
		replace natadoptionday=1 if AdoptDate==mdy(11,22,2003)
		replace natadoptionday=1 if AdoptDate==mdy(11,20,2004)
		replace natadoptionday=1 if AdoptDate==mdy(11,19,2005)
		replace natadoptionday=1 if AdoptDate==mdy(11,18,2006)
		replace natadoptionday=1 if AdoptDate==mdy(11,17,2007)
		replace natadoptionday=1 if AdoptDate==mdy(11,22,2008)
		replace natadoptionday=1 if AdoptDate==mdy(11,21,2009)
		replace natadoptionday=1 if AdoptDate==mdy(11,20,2010)
		replace natadoptionday=1 if AdoptDate==mdy(11,19,2011)
		replace natadoptionday=1 if AdoptDate==mdy(11,24,2012)
		replace natadoptionday=1 if AdoptDate==mdy(11,23,2013)
		replace natadoptionday=1 if AdoptDate==mdy(11,22,2014)
			
		gen t_start=dm-600
		gen t_end=dm-623
		* Start with December-January (t_start = -1 is December 2009 and t_start=0 is January 2010; 
		* t_end=0 is December 2011 and t_end=1 is January 2012)
		gen exclude=t_start==-1 | t_start==0 | t_end==0 | t_end==1 

		* POLYNOMIAL OF TIME
		* Start at July 2002 (dm=510; date=15522)
		gen t=AdoptDate-15522
		forvalues order = 1/6 {
			gen t`order' = t^`order'
			}
			
	* ONE MONTH
		replace exclude=1 if t_start==-2
			
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_start==-2
		sum diff if t_start==-1
		sum diff if t_start==0
		
		sum total_y_hat if t_start ==-2
		sum total_actual if t_start==-2
		
		sum total_y_hat if t_start ==-1
		sum total_actual if t_start==-1

		sum total_y_hat if t_start==0
		sum total_actual if t_start==0
		

		drop y_hat diff total_y_hat total_actual
		end
		
		
		* Estimated numbers of adoptions
		cap program drop bunch_2010
		prog def bunch_2010, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2009
		sum total if t_start==-2
		return scalar diff_avg_nov=r(mean)
		* December 2009
		sum total if t_start==-1
		return scalar diff_avg_dec=r(mean)
		* January 2010
		sum total if t_start==0
		return scalar diff_avg_jan=r(mean) 	
		* November + December + January
		egen total_combined=sum(diff) if dm>=598 & dm<=600
		sum total_combined if t_start==-1
		return scalar diff_avg_all=r(mean) 
		* December + January
		egen total_decjan=sum(diff) if dm>=599 & dm<=600
		sum total_decjan if t_start==-1
		return scalar diff_avg_decjan=r(mean) 
		drop y_hat diff total total_combined total_decjan
		end
		
		foreach var of varlist adopt  {
		local type `var'
		summarystats `type' `poly'
		  bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_all=r(diff_avg_all) diff_avg_decjan=r(diff_avg_decjan), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' `poly'
			}

	* TWO MONTHS
		replace exclude=1 if t_start==1
			
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_start==-2
		sum diff if t_start==-1
		sum diff if t_start==0
		sum diff if t_start==1
		
		sum total_y_hat if t_start ==-2
		sum total_actual if t_start==-2
		
		sum total_y_hat if t_start ==-1
		sum total_actual if t_start==-1

		sum total_y_hat if t_start==0
		sum total_actual if t_start==0
		
		sum total_y_hat if t_start==1
		sum total_actual if t_start==1

		drop y_hat diff total_y_hat total_actual
		end
				
		* Estimated numbers of adoptions
		cap program drop bunch_2010
		prog def bunch_2010, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2009
		sum total if t_start==-2
		return scalar diff_avg_nov=r(mean)
		* December 2009
		sum total if t_start==-1
		return scalar diff_avg_dec=r(mean)
		* January 2010
		sum total if t_start==0
		return scalar diff_avg_jan=r(mean) 	
		* February 2010
		sum total if t_start==1
		return scalar diff_avg_feb=r(mean)
		* 2010 cumulative total
		egen total_2010=sum(diff) if dm>=600&dm<=601
		sum total_2010 if t_start==1
		return scalar diff_avg_2010=r(mean) 
		* November + December + January + February 
		egen total_combined=sum(diff) if dm>=598 & dm<=601
		sum total_combined if t_start==-1
		return scalar diff_avg_all=r(mean) 
		*  December + January + February 
		egen total_decfeb=sum(diff) if dm>=599 & dm<=601
		sum total_decfeb if t_start==-1
		return scalar diff_avg_decfeb=r(mean) 
		drop y_hat diff total total_combined total_2010 total_decfeb
		end
		

		foreach var of varlist adopt  {
		local type `var'
		summarystats `type' `poly'
		  bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_2010=r(diff_avg_2010) diff_avg_all=r(diff_avg_all) diff_avg_decfeb=r(diff_avg_decfeb), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' `poly'
			}

	* THREE MONTHS
		
		replace exclude=1 if t_start==2

		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_start==-2
		sum diff if t_start==-1
		sum diff if t_start==0
		sum diff if t_start==1
		sum diff if t_start==2
		
		sum total_y_hat if t_start ==-2
		sum total_actual if t_start==-2
		
		sum total_y_hat if t_start ==-1
		sum total_actual if t_start==-1

		sum total_y_hat if t_start==0
		sum total_actual if t_start==0
		
		sum total_y_hat if t_start==1
		sum total_actual if t_start==1

		sum total_y_hat if t_start==2
		sum total_actual if t_start==2

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2010
		prog def bunch_2010, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2009
		sum total if t_start==-2
		return scalar diff_avg_nov=r(mean)
		* December 2009
		sum total if t_start==-1
		return scalar diff_avg_dec=r(mean)
		* January 2010
		sum total if t_start==0
		return scalar diff_avg_jan=r(mean) 	
		* February 2010
		sum total if t_start==1
		return scalar diff_avg_feb=r(mean)
		* March 2010
		sum total if t_start==2
		return scalar diff_avg_mar=r(mean)
		* 2010 cumulative total
		egen total_2010=sum(diff) if dm>=600&dm<=602
		sum total_2010 if t_start==1
		return scalar diff_avg_2010=r(mean)
		* November + December + January + February + March
		egen total_combined=sum(diff) if dm>=598 & dm<=602
		sum total_combined if t_start==-1
		return scalar diff_avg_all=r(mean) 
		*  December + January + February + March
		egen total_decmar=sum(diff) if dm>=599 & dm<=602
		sum total_decmar if t_start==-1
		return scalar diff_avg_decmar=r(mean) 
		drop y_hat diff total total_combined total_2010 total_decmar
		end


		foreach var of varlist adopt {
		local type `var'
		summarystats `type' `poly'
		  bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_2010=r(diff_avg_2010) diff_avg_all=r(diff_avg_all) diff_avg_decmar=r(diff_avg_decmar), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' `poly'
			}
			
	* FOUR MONTHS
		
		replace exclude=1 if t_start==3
		
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_start==-2
		sum diff if t_start==-1
		sum diff if t_start==0
		sum diff if t_start==1
		sum diff if t_start==2
		sum diff if t_start==3
		
		sum total_y_hat if t_start ==-2
		sum total_actual if t_start==-2
		
		sum total_y_hat if t_start ==-1
		sum total_actual if t_start==-1

		sum total_y_hat if t_start==0
		sum total_actual if t_start==0
		
		sum total_y_hat if t_start==1
		sum total_actual if t_start==1

		sum total_y_hat if t_start==2
		sum total_actual if t_start==2

		sum total_y_hat if t_start==3
		sum total_actual if t_start==3

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2010
		prog def bunch_2010, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2009
		sum total if t_start==-2
		return scalar diff_avg_nov=r(mean)
		* December 2009
		sum total if t_start==-1
		return scalar diff_avg_dec=r(mean)
		* January 2010
		sum total if t_start==0
		return scalar diff_avg_jan=r(mean) 	
		* February 2010
		sum total if t_start==1
		return scalar diff_avg_feb=r(mean)
		* March 2010
		sum total if t_start==2
		return scalar diff_avg_mar=r(mean)
		* April 2010
		sum total if t_start==3
		return scalar diff_avg_apr=r(mean)
		* 2010 cumulative total
		egen total_2010=sum(diff) if dm>=600&dm<=603
		sum total_2010 if t_start==1
		return scalar diff_avg_2010=r(mean)
		* November + December + January + February + March + April
		egen total_combined=sum(diff) if dm>=598 & dm<=603
		sum total_combined if t_start==-1
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March + April
		egen total_decapr=sum(diff) if dm>=599 & dm<=603
		sum total_decapr if t_start==-1
		return scalar diff_avg_decapr=r(mean) 
		drop y_hat diff total total_combined total_2010 total_decapr
		end
	
	
		foreach var of varlist adopt  {
		local type `var'
		summarystats `type' `poly'
		  bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_apr=r(diff_avg_apr) diff_avg_2010=r(diff_avg_2010) diff_avg_all=r(diff_avg_all) diff_avg_decapr=r(diff_avg_decapr), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' `poly'
			}
			
		
	* FIVE MONTHS
		
		replace exclude=1 if t_start==4
		
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_start==-2
		sum diff if t_start==-1
		sum diff if t_start==0
		sum diff if t_start==1
		sum diff if t_start==2
		sum diff if t_start==3
		sum diff if t_start==4
		
		sum total_y_hat if t_start ==-2
		sum total_actual if t_start==-2
		
		sum total_y_hat if t_start ==-1
		sum total_actual if t_start==-1

		sum total_y_hat if t_start==0
		sum total_actual if t_start==0
		
		sum total_y_hat if t_start==1
		sum total_actual if t_start==1

		sum total_y_hat if t_start==2
		sum total_actual if t_start==2

		sum total_y_hat if t_start==3
		sum total_actual if t_start==3
		
		sum total_y_hat if t_start==4
		sum total_actual if t_start==4

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2010
		prog def bunch_2010, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2009
		sum total if t_start==-2
		return scalar diff_avg_nov=r(mean)		
		* December 2009
		sum total if t_start==-1
		return scalar diff_avg_dec=r(mean)
		* January 2010
		sum total if t_start==0
		return scalar diff_avg_jan=r(mean) 	
		* February 2010
		sum total if t_start==1
		return scalar diff_avg_feb=r(mean)
		* March 2010
		sum total if t_start==2
		return scalar diff_avg_mar=r(mean)
		* April 2010
		sum total if t_start==3
		return scalar diff_avg_apr=r(mean)
		* MAY 2010
		sum total if t_start==4
		return scalar diff_avg_may=r(mean)
		* 2010 cumulative total
		egen total_2010=sum(diff) if dm>=600&dm<=604
		sum total_2010 if t_start==1
		return scalar diff_avg_2010=r(mean)
		* November + December + January + February + March + April + May
		egen total_combined=sum(diff) if dm>=598 & dm<=604
		sum total_combined if t_start==-1
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March + April + May
		egen total_decmay=sum(diff) if dm>=599 & dm<=604
		sum total_decmay if t_start==-1
		return scalar diff_avg_decmay=r(mean) 
		drop y_hat diff total total_combined total_2010 total_decmay
		end
		

		foreach var of varlist adopt  {
		local type `var'
		summarystats `type' `poly'
		  bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_apr=r(diff_avg_apr) diff_avg_may=r(diff_avg_may) diff_avg_2010=r(diff_avg_2010) diff_avg_all=r(diff_avg_all) diff_avg_decmay=r(diff_avg_decmay), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' `poly'
			}
				
			
	* SIX MONTHS
		
		replace exclude=1 if t_start==5
		
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_start==-2
		sum diff if t_start==-1
		sum diff if t_start==0
		sum diff if t_start==1
		sum diff if t_start==2
		sum diff if t_start==3
		sum diff if t_start==4
		sum diff if t_start==5
		
		sum total_y_hat if t_start ==-2
		sum total_actual if t_start==-2
		
		sum total_y_hat if t_start ==-1
		sum total_actual if t_start==-1

		sum total_y_hat if t_start==0
		sum total_actual if t_start==0
		
		sum total_y_hat if t_start==1
		sum total_actual if t_start==1

		sum total_y_hat if t_start==2
		sum total_actual if t_start==2

		sum total_y_hat if t_start==3
		sum total_actual if t_start==3
		
		sum total_y_hat if t_start==4
		sum total_actual if t_start==4
		
		sum total_y_hat if t_start==5
		sum total_actual if t_start==5

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2010
		prog def bunch_2010, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2009
		sum total if t_start==-2
		return scalar diff_avg_nov=r(mean)		
		* December 2009
		sum total if t_start==-1
		return scalar diff_avg_dec=r(mean)
		* January 2010
		sum total if t_start==0
		return scalar diff_avg_jan=r(mean) 	
		* February 2010
		sum total if t_start==1
		return scalar diff_avg_feb=r(mean)
		* March 2010
		sum total if t_start==2
		return scalar diff_avg_mar=r(mean)
		* April 2010
		sum total if t_start==3
		return scalar diff_avg_apr=r(mean)
		* MAY 2010
		sum total if t_start==4
		return scalar diff_avg_may=r(mean)
		* JUNE 2010
		sum total if t_start==5
		return scalar diff_avg_jun=r(mean)
		* 2010 cumulative total
		egen total_2010=sum(diff) if dm>=600&dm<=605
		sum total_2010 if t_start==1
		return scalar diff_avg_2010=r(mean)
		* November + December + January + February + March + April + May + June
		egen total_combined=sum(diff) if dm>=598 & dm<=605
		sum total_combined if t_start==-1
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March + April + May + June
		egen total_decjun=sum(diff) if dm>=599 & dm<=605
		sum total_decjun if t_start==-1
		return scalar diff_avg_decjun=r(mean) 
		drop y_hat diff total total_combined total_2010 total_decjun
		end
		
		foreach var of varlist adopt {
		local type `var'
		summarystats `type' `poly'
		bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_apr=r(diff_avg_apr) diff_avg_may=r(diff_avg_may) diff_avg_jun=r(diff_avg_jun) diff_avg_2010=r(diff_avg_2010) diff_avg_all=r(diff_avg_all) diff_avg_decjun=r(diff_avg_decjun), reps(500) seed(123) cluster(doy) nodrop: bunch_2010 `type' `poly'
			}
			
***************************
*        TABLE 4          *
***************************

* AROUND EXPIRATION
		
	* LOAD DATA, CREATE BALANCED PANEL
	
		local poly=4
	
		use "$folder/temp_ad.dta",clear
		set more off
		
		collapse (sum) adopt, by(AdoptDate)
		
		gen year=year(AdoptDate)
		gen month=month(AdoptDate)
		gen day=day(AdoptDate)
		
		* BALANCED PANEL
		sort month day year
		fillin month day year
		replace AdoptDate=mdy(month, day, year) if missing(AdoptDate)
		drop if missing(AdoptDate)
		drop if AdoptDate<=mdy(1,1,2000)
		replace adopt=0 if _fillin==1
	
		gen doy=mdy(month, day, 1968)
		gen dow=dow(AdoptDate) /* 0 is sunday */
		
		gen dm=mofd(AdoptDate)
		
		drop if AdoptDate<mdy(7,1,2002)
		drop if AdoptDate>=mdy(10,1,2015)
		
		sort AdoptDate
		
		* Controlling for national adoption day (Saturday before Thanksgiving, where Thanksgiving is the fourth Thursday in November)
		gen natadoptionday=0
		replace natadoptionday=1 if AdoptDate==mdy(11,23,2002)
		replace natadoptionday=1 if AdoptDate==mdy(11,22,2003)
		replace natadoptionday=1 if AdoptDate==mdy(11,20,2004)
		replace natadoptionday=1 if AdoptDate==mdy(11,19,2005)
		replace natadoptionday=1 if AdoptDate==mdy(11,18,2006)
		replace natadoptionday=1 if AdoptDate==mdy(11,17,2007)
		replace natadoptionday=1 if AdoptDate==mdy(11,22,2008)
		replace natadoptionday=1 if AdoptDate==mdy(11,21,2009)
		replace natadoptionday=1 if AdoptDate==mdy(11,20,2010)
		replace natadoptionday=1 if AdoptDate==mdy(11,19,2011)
		replace natadoptionday=1 if AdoptDate==mdy(11,24,2012)
		replace natadoptionday=1 if AdoptDate==mdy(11,23,2013)
		replace natadoptionday=1 if AdoptDate==mdy(11,22,2014)
			
		gen t_start=dm-600
		gen t_end=dm-623
		gen exclude=t_start==-1 | t_start==0 | t_end==0 | t_end==1 
		
		* POLYNOMIAL OF TIME
		* Start at July 2002 (dm=510; date=15522)
		gen t=AdoptDate-15522
		forvalues order = 1/6 {
			gen t`order' = t^`order'
			}
	
	* ONE MONTH
		replace exclude=1 if t_end==-1
	
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_end==-1
		sum diff if t_end==0
		sum diff if t_end==1
	
		sum total_y_hat if t_end ==0
		sum total_actual if t_end==0

		sum total_y_hat if t_end==1
		sum total_actual if t_end==1
		
		drop y_hat diff total_y_hat total_actual
		end
		
		* Estimated numbers of adoptions
		cap program drop bunch_2012
		prog def bunch_2012, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */	
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2011
		sum total if t_end==-1
		return scalar diff_avg_nov=r(mean)
		* December 2011
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 2012
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 	
		* November + December
		egen total_novdec=sum(diff) if dm>=622 & dm<=623
		sum total_novdec if t_end==0
		return scalar diff_avg_novdec=r(mean)
		* November + December + January
		egen total_combined=sum(diff) if dm>=622 & dm<=624
		sum total_combined if t_end==0
		return scalar diff_avg_all=r(mean) 
		* December + January
		egen total_decjan=sum(diff) if dm>=623 & dm<=624
		sum total_decjan if t_end==0
		return scalar diff_avg_decjan=r(mean)
		drop y_hat diff total total_combined total_decjan total_novdec
		end
		
		foreach var of varlist adopt {
			local type `var'
			summarystats `type' `poly'
			bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_novdec=r(diff_avg_novdec) diff_avg_all=r(diff_avg_all) diff_avg_decjan=r(diff_avg_decjan), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' `poly'
			}
		
	* TWO MONTHS
		replace exclude=1 if t_end==2
	
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_end==0
		sum diff if t_end==1
		sum diff if t_end==2
		
		sum total_y_hat if t_end ==0
		sum total_actual if t_end==0

		sum total_y_hat if t_end==1
		sum total_actual if t_end==1
		
		sum total_y_hat if t_end==2
		sum total_actual if t_end==2

		drop y_hat diff total_y_hat total_actual
		end
		
		* Estimated numbers of adoptions
		cap program drop bunch_2012
		prog def bunch_2012, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */	
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2011
		sum total if t_end==-1
		return scalar diff_avg_nov=r(mean)
		* December 2011
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 2012
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 	
		* February 2012
		sum total if t_end==2
		return scalar diff_avg_feb=r(mean)
		* November + December
		egen total_novdec=sum(diff) if dm>=622 & dm<=623
		sum total_novdec if t_end==0
		return scalar diff_avg_novdec=r(mean)
		* 2012 cumulative total
		egen total_2012=sum(diff) if dm>=624&dm<=625
		sum total_2012 if t_end==1
		return scalar diff_avg_2012=r(mean) 
		* November + December + January + February
		egen total_combined=sum(diff) if dm>=622 & dm<=625
		sum total_combined if t_end==0
		return scalar diff_avg_all=r(mean)
		* December + January + February
		egen total_decfeb=sum(diff) if dm>=623 & dm<=625
		sum total_decfeb if t_end==0
		return scalar diff_avg_decfeb=r(mean)
		drop y_hat diff total total_2012 total_combined total_novdec total_decfeb
		end
		
		foreach var of varlist adopt {
			local type `var'
			summarystats `type' `poly'
			bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_novdec=r(diff_avg_novdec) diff_avg_2012=r(diff_avg_2012) diff_avg_all=r(diff_avg_all) diff_avg_decfeb=r(diff_avg_decfeb), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' `poly'
			}
		

	* THREE MONTHS
		replace exclude=1 if t_end==3

		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_end==0
		sum diff if t_end==1
		sum diff if t_end==2
		sum diff if t_end==3
		
		sum total_y_hat if t_end ==0
		sum total_actual if t_end==0

		sum total_y_hat if t_end==1
		sum total_actual if t_end==1
		
		sum total_y_hat if t_end==2
		sum total_actual if t_end==2

		sum total_y_hat if t_end==3
		sum total_actual if t_end==3

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2012
		prog def bunch_2012, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2011
		sum total if t_end==-1
		return scalar diff_avg_nov=r(mean)
		* December 2011
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 2012
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 	
		* February 2012
		sum total if t_end==2
		return scalar diff_avg_feb=r(mean)
		* March 2012
		sum total if t_end==3
		return scalar diff_avg_mar=r(mean)
		* November + December
		egen total_novdec=sum(diff) if dm>=622 & dm<=623
		sum total_novdec if t_end==0
		return scalar diff_avg_novdec=r(mean)
		* 2012 cumulative total
		egen total_2012=sum(diff) if dm>=624&dm<=626
		sum total_2012 if t_end==1
		return scalar diff_avg_2012=r(mean) 
		* November + December + January + February + March
		egen total_combined=sum(diff) if dm>=622 & dm<=626
		sum total_combined if t_end==0
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March
		egen total_decmar=sum(diff) if dm>=623 & dm<=626
		sum total_decmar if t_end==0
		return scalar diff_avg_decmar=r(mean)
		drop y_hat diff total total_2012 total_combined total_novdec total_decmar
		end
		
		foreach var of varlist adopt {
			local type `var'
			summarystats `type' `poly'		
			bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_novdec=r(diff_avg_novdec) diff_avg_2012=r(diff_avg_2012) diff_avg_all=r(diff_avg_all) diff_avg_decmar=r(diff_avg_decmar), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' `poly'
			}
		
		
	* FOUR MONTHS
		replace exclude=1 if t_end==4
	
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_end==0
		sum diff if t_end==1
		sum diff if t_end==2
		sum diff if t_end==3
		sum diff if t_end==4
		
		sum total_y_hat if t_end ==0
		sum total_actual if t_end==0

		sum total_y_hat if t_end==1
		sum total_actual if t_end==1
		
		sum total_y_hat if t_end==2
		sum total_actual if t_end==2

		sum total_y_hat if t_end==3
		sum total_actual if t_end==3

		sum total_y_hat if t_end==4
		sum total_actual if t_end==4

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2012
		prog def bunch_2012, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2011
		sum total if t_end==-1
		return scalar diff_avg_nov=r(mean)
		* December 2011
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 2012
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 	
		* February 2012
		sum total if t_end==2
		return scalar diff_avg_feb=r(mean)
		* March 2012
		sum total if t_end==3
		return scalar diff_avg_mar=r(mean)
		* April 2012
		sum total if t_end==4
		return scalar diff_avg_apr=r(mean)
		* November + December
		egen total_novdec=sum(diff) if dm>=622 & dm<=623
		sum total_novdec if t_end==0
		return scalar diff_avg_novdec=r(mean)
		* 2012 cumulative total
		egen total_2012=sum(diff) if dm>=624&dm<=627
		sum total_2012 if t_end==1
		return scalar diff_avg_2012=r(mean) 
		* November + December + January + February + March + April
		egen total_combined=sum(diff) if dm>=622 & dm<=627
		sum total_combined if t_end==0
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March + April
		egen total_decapr=sum(diff) if dm>=623 & dm<=627
		sum total_decapr if t_end==0
		return scalar diff_avg_decapr=r(mean)
		drop y_hat diff total total_2012 total_combined total_decapr total_novdec
		end
	
		foreach var of varlist adopt {
			local type `var'
			summarystats `type' `poly'
			bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_apr=r(diff_avg_apr) diff_avg_novdec=r(diff_avg_novdec) diff_avg_2012=r(diff_avg_2012) diff_avg_all=r(diff_avg_all) diff_avg_decapr=r(diff_avg_decapr), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' `poly'
			}
	
		
	* FIVE MONTHS
		replace exclude=1 if t_end==5
	
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_end==0
		sum diff if t_end==1
		sum diff if t_end==2
		sum diff if t_end==3
		sum diff if t_end==4
		sum diff if t_end==5
		
		sum total_y_hat if t_end ==0
		sum total_actual if t_end==0

		sum total_y_hat if t_end==1
		sum total_actual if t_end==1
		
		sum total_y_hat if t_end==2
		sum total_actual if t_end==2

		sum total_y_hat if t_end==3
		sum total_actual if t_end==3

		sum total_y_hat if t_end==4
		sum total_actual if t_end==4
		
		sum total_y_hat if t_end==5
		sum total_actual if t_end==5

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2012
		prog def bunch_2012, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2011
		sum total if t_end==-1
		return scalar diff_avg_nov=r(mean)
		* December 2011
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 2012
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 	
		* February 2012
		sum total if t_end==2
		return scalar diff_avg_feb=r(mean)
		* March 2012
		sum total if t_end==3
		return scalar diff_avg_mar=r(mean)
		* April 2012
		sum total if t_end==4
		return scalar diff_avg_apr=r(mean)
		* MAY 2012
		sum total if t_end==5
		return scalar diff_avg_may=r(mean)
		* November + December
		egen total_novdec=sum(diff) if dm>=622 & dm<=623
		sum total_novdec if t_end==0
		return scalar diff_avg_novdec=r(mean)
		* 2012 cumulative total
		egen total_2012=sum(diff) if dm>=624&dm<=628
		sum total_2012 if t_end==1
		return scalar diff_avg_2012=r(mean) 
		* November + December + January + February + March + April + May
		egen total_combined=sum(diff) if dm>=622 & dm<=628
		sum total_combined if t_end==0
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March + April + May
		egen total_decmay=sum(diff) if dm>=623 & dm<=628
		sum total_decmay if t_end==0
		return scalar diff_avg_decmay=r(mean)
		drop y_hat diff total total_2012 total_combined total_novdec total_decmay
		end
		
		foreach var of varlist adopt {
			local type `var'
			summarystats `type' `poly'
			bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_apr=r(diff_avg_apr) diff_avg_may=r(diff_avg_may) diff_avg_novdec=r(diff_avg_novdec) diff_avg_2012=r(diff_avg_2012) diff_avg_all=r(diff_avg_all) diff_avg_decmay=r(diff_avg_decmay), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' `poly'
			}
		
		
	* SIX MONTHS
	
		replace exclude=1 if t_end==6
		local poly=4	
		* Actual versus predicted summary statistics for table
		cap program drop summarystats
		prog def summarystats, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)	
		predict y_hat 		
		egen total_actual=sum(`type'), by(dm)
		egen total_y_hat=sum(y_hat), by(dm)
		gen diff= total_actual - total_y_hat
		sum diff if t_end==0
		sum diff if t_end==1
		sum diff if t_end==2
		sum diff if t_end==3
		sum diff if t_end==4
		sum diff if t_end==5
		sum diff if t_end==6
		
		sum total_y_hat if t_end ==0
		sum total_actual if t_end==0

		sum total_y_hat if t_end==1
		sum total_actual if t_end==1
		
		sum total_y_hat if t_end==2
		sum total_actual if t_end==2

		sum total_y_hat if t_end==3
		sum total_actual if t_end==3

		sum total_y_hat if t_end==4
		sum total_actual if t_end==4
		
		sum total_y_hat if t_end==5
		sum total_actual if t_end==5

		sum total_y_hat if t_end==6
		sum total_actual if t_end==6

		drop y_hat diff total_y_hat total_actual
		end
		
		cap program drop bunch_2012
		prog def bunch_2012, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */																								/* Obtain the results using observations not in the donut */
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* November 2011
		sum total if t_end==-1
		return scalar diff_avg_nov=r(mean)
		* December 2011
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 2012
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 	
		* February 2012
		sum total if t_end==2
		return scalar diff_avg_feb=r(mean)
		* March 2012
		sum total if t_end==3
		return scalar diff_avg_mar=r(mean)
		* April 2012
		sum total if t_end==4
		return scalar diff_avg_apr=r(mean)
		* MAY 2012
		sum total if t_end==5
		return scalar diff_avg_may=r(mean)
		* JUNE 2012
		sum total if t_end==6
		return scalar diff_avg_jun=r(mean)
		* November + December
		egen total_novdec=sum(diff) if dm>=622 & dm<=623
		sum total_novdec if t_end==0
		return scalar diff_avg_novdec=r(mean)
		* 2012 cumulative total
		egen total_2012=sum(diff) if dm>=624&dm<=629
		sum total_2012 if t_end==1
		return scalar diff_avg_2012=r(mean) 
		* November+ December + January + February + March + April + May + June
		egen total_combined=sum(diff) if dm>=622 & dm<=629
		sum total_combined if t_end==0
		return scalar diff_avg_all=r(mean) 
		* December + January + February + March + April + May + June
		egen total_decjun=sum(diff) if dm>=623 & dm<=629
		sum total_decjun if t_end==0
		return scalar diff_avg_decjun=r(mean)
		drop y_hat diff total total_2012 total_combined total_decjun total_novdec
		end
		
	foreach var of varlist adopt {
		local type `var'
		 summarystats `type' `poly'
		 bootstrap diff_avg_nov=r(diff_avg_nov) diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan) diff_avg_feb=r(diff_avg_feb) diff_avg_mar=r(diff_avg_mar) diff_avg_apr=r(diff_avg_apr) diff_avg_may=r(diff_avg_may) diff_avg_jun=r(diff_avg_jun) diff_avg_novdec=r(diff_avg_novdec) diff_avg_2012=r(diff_avg_2012) diff_avg_all=r(diff_avg_all) diff_avg_decjun=r(diff_avg_decjun), reps(500) seed(123) cluster(doy) nodrop: bunch_2012 `type' `poly'
		}
				 

***************************
*        TABLE 5          *
***************************
	
	use "$folder/temp_ad.dta",clear
	set more off	
	collapse (sum) adopt, by(AdoptDate)

	gen year=year(AdoptDate)
	gen month=month(AdoptDate)
	gen day=day(AdoptDate)

	sort month day year
	fillin month day year
	replace AdoptDate=mdy(month, day, year) if missing(AdoptDate)
	drop if missing(AdoptDate)
	drop if AdoptDate<=mdy(1,1,2000)
	replace adopt=0 if _fillin==1
				
	gen doy=mdy(month, day, 1968)
	gen dow=dow(AdoptDate) /* 0 is sunday */

	gen dm=mofd(AdoptDate)

	drop if AdoptDate<mdy(7,1,2002)
	drop if AdoptDate>=mdy(10,1,2015)

	sort AdoptDate
				
	gen natadoptionday=0
	replace natadoptionday=1 if AdoptDate==mdy(11,23,2002)
	replace natadoptionday=1 if AdoptDate==mdy(11,22,2003)
	replace natadoptionday=1 if AdoptDate==mdy(11,20,2004)
	replace natadoptionday=1 if AdoptDate==mdy(11,19,2005)
	replace natadoptionday=1 if AdoptDate==mdy(11,18,2006)
	replace natadoptionday=1 if AdoptDate==mdy(11,17,2007)
	replace natadoptionday=1 if AdoptDate==mdy(11,22,2008)
	replace natadoptionday=1 if AdoptDate==mdy(11,21,2009)
	replace natadoptionday=1 if AdoptDate==mdy(11,20,2010)
	replace natadoptionday=1 if AdoptDate==mdy(11,19,2011)
	replace natadoptionday=1 if AdoptDate==mdy(11,24,2012)
	replace natadoptionday=1 if AdoptDate==mdy(11,23,2013)
	replace natadoptionday=1 if AdoptDate==mdy(11,22,2014)
				
	gen t_start=dm-600
	gen t_end=dm-623
	gen exclude=t_start==-1 | t_start==0 | t_end==0 | t_end==1

	* POLYNOMIAL OF TIME
	* Start at July 2002 (dm=510; date=15522)
	gen t=AdoptDate-15522
	forvalues order = 1/4 {
		gen t`order' = t^`order'
		}

	* Using end program
	cap program drop bunch_placebo
		prog def bunch_placebo, rclass
		args type order
		reg `type' i.dow i.month i.year i.natadoptionday t1-t`order' if exclude==0, cluster(doy)		/* Obtain the results using observations not in the donut */
		predict y_hat 																		/* predict values for all observations */
		gen diff= `type' - y_hat
		egen total=sum(diff), by(dm)
		* December 
		sum total if t_end==0
		return scalar diff_avg_dec=r(mean)
		* January 
		sum total if t_end==1
		return scalar diff_avg_jan=r(mean) 																/* Average across (y - yhat) for all observations */
		drop y_hat diff total
	end
	
	forval i=2002(1)2014 {
		drop t_end exclude
		local j=mofd(mdy(12,1,`i'))
		gen t_end=dm-`j'
		gen exclude= t_end==0 | t_end==1
		replace exclude=1 if dm==623
		replace exclude=1 if dm==624
		replace exclude=1 if dm==599
		replace exclude=1 if dm==600
		sum dm if t_end==0

	local type adopt 4
	di `i'
	 bootstrap diff_avg_dec=r(diff_avg_dec) diff_avg_jan=r(diff_avg_jan), reps(500) seed(123) cluster(doy) nodrop: bunch_placebo `type' `k'
	summarystats adopt 4
	
	}
		
		
		
log close


