* The code in this file replicates output provided in Tables 6 and 7.

cap log close
log using "$folder/${date_string}_tables6_7.log", replace 

use "$folder/temp_ad.dta",clear
set more off

drop if AdoptDate<mdy(7,1,2002)

gen month=month(AdoptDate)

* Collapse number of adoptions by day
gen count=1
collapse (sum) count, by(AdoptDate )
gen year=year(AdoptDate)
gen fy=year
replace fy=year+1 if month(AdoptDate)>=10
gen dow=dow(AdoptDate) /* 0 is sunday */
gen first=mdy(1,1,year(AdoptDate))
gen month=month(AdoptDate)
gen day=day(AdoptDate)

* BALANCED PANEL
fillin month day year
replace AdoptDate=mdy(month, day, year) if missing(AdoptDate)
replace count=0 if _fillin==1
replace fy=year if missing(fy)
replace dow=dow(AdoptDate) if missing(dow)
drop if year==2002 & month==1
drop if year==2002 & month==2

gen doy=mdy(month, day, 1968)
drop if missing(AdoptDate)
drop if AdoptDate<mdy(7,1,2002)
drop if AdoptDate>=mdy(10,1,2015)
drop if missing(AdoptDate)

* TIMING: INDICATORS FOR EACH MONTH

* AROUND CREDIT INTRODUCTION	
gen B0=month(AdoptDate)==10 & year(AdoptDate)==2009
gen B1=month(AdoptDate)==11 & year(AdoptDate)==2009
gen B2=month(AdoptDate)==12 & year(AdoptDate)==2009
gen B3=month(AdoptDate)==1 & year(AdoptDate)==2010
gen B4=month(AdoptDate)==2 & year(AdoptDate)==2010
gen B5=month(AdoptDate)==3 & year(AdoptDate)==2010
gen B6=month(AdoptDate)==4 & year(AdoptDate)==2010
gen B7=month(AdoptDate)==5 & year(AdoptDate)==2010
gen B8=month(AdoptDate)==6 & year(AdoptDate)==2010
gen B9=month(AdoptDate)==7 & year(AdoptDate)==2010
gen B10=month(AdoptDate)==8 & year(AdoptDate)==2010
gen B11=month(AdoptDate)==9 & year(AdoptDate)==2010
gen B12=month(AdoptDate)==10 & year(AdoptDate)==2010
gen B13=month(AdoptDate)==11 & year(AdoptDate)==2010
gen B14=month(AdoptDate)==12 & year(AdoptDate)==2010	

* AROUND CREDIT EXPIRATION 
gen I0=month(AdoptDate)==10 & year(AdoptDate)==2011
gen I1=month(AdoptDate)==11 & year(AdoptDate)==2011
gen I2=month(AdoptDate)==12 & year(AdoptDate)==2011
gen I3=month(AdoptDate)==1 & year(AdoptDate)==2012
gen I4=month(AdoptDate)==2 & year(AdoptDate)==2012
gen I5=month(AdoptDate)==3 & year(AdoptDate)==2012
gen I6=month(AdoptDate)==4 & year(AdoptDate)==2012
gen I7=month(AdoptDate)==5 & year(AdoptDate)==2012
gen I8=month(AdoptDate)==6 & year(AdoptDate)==2012
gen I9=month(AdoptDate)==7 & year(AdoptDate)==2012
gen I10=month(AdoptDate)==8 & year(AdoptDate)==2012
gen I11=month(AdoptDate)==9 & year(AdoptDate)==2012
gen I12=month(AdoptDate)==10 & year(AdoptDate)==2012
gen I13=month(AdoptDate)==11 & year(AdoptDate)==2012
gen I14=month(AdoptDate)==12 & year(AdoptDate)==2012
gen sum=I1+I2+I3+I4+I5+I6+I7+I8
tab month if sum==1
tab year if sum==1

gen natadoptionday=0
replace natadoptionday=1 if AdoptDate==mdy(11,23,2002)
replace natadoptionday=1 if AdoptDate==mdy(11,22,2003)
replace natadoptionday=1 if AdoptDate==mdy(11,20,2004)
replace natadoptionday=1 if AdoptDate==mdy(11,19,2005)
replace natadoptionday=1 if AdoptDate==mdy(11,18,2006)
replace natadoptionday=1 if AdoptDate==mdy(11,17,2007)
replace natadoptionday=1 if AdoptDate==mdy(11,22,2008)
replace natadoptionday=1 if AdoptDate==mdy(11,21,2009)
replace natadoptionday=1 if AdoptDate==mdy(11,20,2010)
replace natadoptionday=1 if AdoptDate==mdy(11,19,2011)
replace natadoptionday=1 if AdoptDate==mdy(11,24,2012)
replace natadoptionday=1 if AdoptDate==mdy(11,23,2013)
replace natadoptionday=1 if AdoptDate==mdy(11,22,2014)

* POLYNOMIAL OF TIME
* Start at July 2002 (dm=510; date=15522)
gen t=AdoptDate-15522
forvalues order = 1/6 {
	gen t`order' = t^`order'
	}

* MERGE IN VALUE OF TAX CREDIT
merge m:1 year using "$folder/taxcreditamounts.dta"
keep if _merge==3
drop _merge
* INFLATE CREDIT TO 2015 DOLLARS
merge m:1 year using "$folder/CPI.dta"
keep if _merge==3

gen realmaxamount=maxamount*242.247/cpi

***************************
*        TABLE 6          *
***************************	

	* DECEMBER - JUNE, CREDIT INTRODUCTION 
	
		gen sample=1
		replace sample =0 if year==2011 & month==12
		replace sample =0 if year==2011 & month==11
		replace sample =0 if year==2012 & month>=1 & month<=7
		
			*CHOOSE POLYNOMIAL SIZE BY MINIMIZING BIC
			
			* Regression of overall number of adoptions
			forvalues order = 1/6 {
			qui areg count i.B2 i.B3 i.B4 i.B5 i.B6 i.B7 i.B8 i.fy i.dow i.natadoptionday t1-t`order' if sample ==1 & (month>=11 | month<=7), absorb(doy) cluster(doy)
					estimates store est_`order'
				}
			estimates stats *
			
			*IDENTIFY POLYNOMIAL WITH MIN BIC
			matrix a = r(S)
			local poly = 1
			local value = a[1,6]
			forvalues order = 2/6 {
				if a[`order',6] < `value' local poly = `order'
				if a[`order',6] < `value' local value = a[`order',6] 
			}

			di "BIC minimizing polynomial = `poly'"
			estimates clear
			
	
		areg count i.B2 i.B3 i.B4 i.B5 i.B6 i.B7 i.B8 i.fy i.dow i.natadoptionday t1-t`poly' if sample ==1 & (month>=11 | month<=7), absorb(doy) cluster(doy)
		test 1.B3 1.B4 1.B5 1.B6 1.B7 1.B8
		outreg2 I* using "$folder/table6.xls", replace se auto(2) ctitle(beginning)
		* 1 month
		lincom (1.B2*31)
		lincom (1.B3*31)
		lincom (1.B2*31 + 1.B3*31)
		* 2 months
		lincom (1.B3*31 + 1.B4*28)
		lincom (1.B2*31 + 1.B3*31 + 1.B4*28)
		* 3 months
		lincom (1.B3*31 + 1.B4*28 + 1.B5*31)
		lincom (1.B2*31 + 1.B3*31 + 1.B4*28 + 1.B5*31)
		* 4 months
		lincom (1.B3*31 + 1.B4*28 + 1.B5*31 + 1.B6*30)
		lincom (1.B2*31 + 1.B3*31 + 1.B4*28 + 1.B5*31 + 1.B6*30)
		* 5 months
		lincom (1.B3*31 + 1.B4*28 + 1.B5*31 + 1.B6*30 + 1.B7*31)
		lincom (1.B2*31 + 1.B3*31 + 1.B4*28 + 1.B5*31 + 1.B6*30 + 1.B7*31)
		* 6 months
		lincom (1.B3*31 + 1.B4*28 + 1.B5*31 + 1.B6*30 + 1.B7*31 + 1.B8*30)
		lincom (1.B2*31 + 1.B3*31 + 1.B4*28 + 1.B5*31 + 1.B6*30 + 1.B7*31+ 1.B8*30)

***************************
*        TABLE 7          *
***************************

	* DECEMBER - JUNE, CREDIT EXPIRATION 
	
		drop sample
		gen sample=1
		replace sample =0 if year==2009 & month==12
		replace sample =0 if year==2009 & month==11
		replace sample =0 if year==2010 & month>=1 & month<=7

		
						
		*CHOOSE POLYNOMIAL SIZE BY MINIMIZING BIC
			
			* Regression of overall number of adoptions
			forvalues order = 1/6 {
			qui areg count i.I2 i.I3 i.I4 i.I5 i.I6 i.I7 i.I8 i.fy i.dow i.natadoptionday t1-t`order' if sample ==1 & (month>=11 | month<=7), absorb(doy) cluster(doy)
					estimates store est_`order'
				}
			estimates stats *
			
			*IDENTIFY POLYNOMIAL WITH MIN BIC
			matrix a = r(S)
			local poly = 1
			local value = a[1,6]
			forvalues order = 2/6 {
				if a[`order',6] < `value' local poly = `order'
				if a[`order',6] < `value' local value = a[`order',6] 
			}

			di "BIC minimizing polynomial = `poly'"
			estimates clear
			
			areg count i.I2 i.I3 i.I4 i.I5 i.I6 i.I7 i.I8 i.fy i.dow i.natadoptionday t1-t`poly' if sample ==1 & (month>=11 | month<=7), absorb(doy) cluster(doy)
			test 1.I3 1.I4 1.I5 1.I6 1.I7 1.I8
			outreg2 I* using "$folder/table7.xls", append se auto(2) ctitle(expiration)
			* 1 month
			lincom (1.I2*31)
			lincom (1.I3*31)
			lincom (1.I2*31 + 1.I3*31)
			* 2 months
			lincom (1.I3*31 + 1.I4*28)
			lincom (1.I2*31 + 1.I3*31 + 1.I4*28)
			* 3 months
			lincom (1.I3*31 + 1.I4*28 + 1.I5*31)
			lincom (1.I2*31 + 1.I3*31 + 1.I4*28 + 1.I5*31)
			* 4 months
			lincom (1.I3*31 + 1.I4*28 + 1.I5*31 + 1.I6*30)
			lincom (1.I2*31 + 1.I3*31 + 1.I4*28 + 1.I5*31 + 1.I6*30)
			* 5 months
			lincom (1.I3*31 + 1.I4*28 + 1.I5*31 + 1.I6*30 + 1.I7*31)
			lincom (1.I2*31 + 1.I3*31 + 1.I4*28 + 1.I5*31 + 1.I6*30 + 1.I7*31)
			* 6 months
			lincom (1.I3*31 + 1.I4*28 + 1.I5*31 + 1.I6*30 + 1.I7*31 + 1.I8*30)
			lincom (1.I2*31 + 1.I3*31 + 1.I4*28 + 1.I5*31 + 1.I6*30 + 1.I7*31+ 1.I8*30)


log close


	
