* The code in this file replicates output provided in Tables 8 and 9.

cap log close
log using "$folder/${date_string}_tables8_9.log", replace 


use "$folder/temp_ad.dta",clear
set more off

drop if AdoptDate<mdy(7,1,2002)
drop if AdoptDate>=mdy(10,1,2015)

gen month=month(AdoptDate)
gen fy=year
replace fy=year+1 if month(AdoptDate)>=10
gen Irefund=year>=2010 & year<=2011
gen dow=dow(AdoptDate) /* 0 is sunday */
gen first=mdy(1,1,year(AdoptDate))
gen day=day(AdoptDate)
gen doy=mdy(month, day, 1968)
gen momsingle=unmarried==1 | singlef==1
replace momsingle=. if missing(singlef)
replace momsingle=. if missing(unmarried)
gen foster=fosparch==1 & otherel==0
	
* SIBLING GROUPS (BUCKLES 2013: STATE, SAME DAY, BIRTH PARENTS' YEARS OF BIRTH AND MARITAL STATUS WERE THE SAME)
egen id=concat(dobyrmom dobyrdad momarrd AdoptDate state)
replace id="." if missing(dobyrmom) | missing(dobyrdad) | missing(momarrd) | missing(AdoptDate) | missing(state)
sort id
by id: gen sibgroup=1 if _n==1
replace sibgroup=sum(sibgroup)
replace sibgroup=. if id=="."
sort sibgroup
quietly by sibgroup: gen sibcount= cond(_N==1, 1, _N) if sibgroup!=1
replace sibcount=0 if missing(sibcount)
gen issib=sibcount>1
replace issib=. if id=="."
gen male=sex==1
replace male=. if missing(sex)
gen pos=monamnt>0
replace pos=. if missing(monamnt)

gen sample=1
replace sample =0 if year==2009 & month==12
replace sample =0 if year==2009 & month==11
replace sample =0 if year==2010 & month==1
replace sample =0 if year==2010 & month==2

sum monamnt
local cap =r(mean)+2*r(sd)
drop if monamnt>`cap' & !missing(monamnt)
drop if AgeAtAdopt>=19
drop if admomage<18 & !missing(admomage)
drop if admomage>100 & !missing(admomage)
drop if addadage<18 & !missing(addadage)
drop if admomage>100 & !missing(addadage)
drop if state==72


* POLYNOMIAL OF TIME
* Start at July 2002 (dm=510; date=15522)
gen t=AdoptDate-15522
forvalues order = 1/6 {
	gen t`order' = t^`order'
	}
	
gen single=singlef
replace single=1 if singlem==1

global covariates i.fy i.dow i.state

***************************
*        TABLE 8         *
***************************	

foreach var of varlist admomage addadage nonhispblackm nonhispwhitem hispanicm married momsingle fosparch olderrel nonrel {
	forval i=1/6 {
	di `i'
	areg `var' i.Irefund $covariates if sample ==1 & (month==12 | month<=`i'), absorb(doy) cluster(doy)
	sum `var' if e(sample)
	}
	}
		
***************************
*        TABLE 9          *
***************************	

	foreach var of varlist AgeAtAdopt male nonhispwhite nonhispblack hispanic sn issib  {
		forval i=1/6 {
		di `i'
		areg `var' i.Irefund $covariates if sample ==1 & (month==12 | month<=`i'), absorb(doy) cluster(doy)
		sum `var' if e(sample)
		}
		}
		
	foreach var of varlist pos  {
		forval i=1/6 {
		di `i'
		areg `var' i.Irefund $covariates if sample ==1 & (month==12 | month<=`i'), absorb(doy) cluster(doy)
		sum `var' if e(sample)
		}
		}

	* Subsidy amount conditional on receipt
	forval i=1/6 {
		di `i'
		areg monamnt_inf i.Irefund $covariates if sample ==1 & (month==12 | month<=`i') & pos==1, absorb(doy) cluster(doy)
		sum monamnt_inf if e(sample)
		}

log close	

